import GoogleCalendar from './GoogleCalendar';
import GameSource from './GameSource';
import fs from 'fs';
import Ics from './Ics';

const CronJob = require('cron').CronJob;


class App {
  googleCalendar: GoogleCalendar;
  gameSource: GameSource;
  ics: Ics;
  googleToken: string;

  constructor() {
    this.googleCalendar = new GoogleCalendar();
    this.gameSource = new GameSource();
    this.ics = new Ics();
    
  }

  async init() {
    console.log("INIT APP")
    await this.googleCalendar.init();
  }

  async getNewGamesAndUpdateCalendar() {
    console.log("GET NEW GAMES AND UPDATE CALENDAR")
    const games = await this.gameSource.getGamesFromHaifa();
    this.googleCalendar.updateNewEvent(games);
  }
}

const app = new App();


const job = new CronJob(
  "0 10 * * *",
  async () => {
    console.log("START")
    const outputFileLocation = 'maccabi-haifa-fc.ics';
    const games = await app.gameSource.getGamesFromHaifa();
    const icsEvents = app.ics.generateIcsOutputFromGames(games);
    fs.writeFileSync(outputFileLocation, icsEvents);
  },
  null,
  true,
  'Asia/Jerusalem'
);
 

